@@ -1027,7 +1027,7 @@ h = la - n
 IF ( h == 0 ) RETURN
 IF ( h > 0 ) GO TO 10
 ! WRITE(6,*) 'ERROR: LA ARGUMENT IN PACK MUST BE .GE. N ARGUMENT'
-STOP
+RETURN
 10    i = 0
 k = 1
 l = n
@@ -1152,7 +1152,7 @@ v(1,1) = 1./v(1,1)
 RETURN
 120   continue
 !WRITE(6,*) 'ERROR: MATRIX HAS NO INVERSE'
-STOP
+!STOP
 END SUBROUTINE vert
 
 
